using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Utils.Log;
using PhoenixDLL;
using Components.Agenda.GUI;
using Components.Agenda.Management;
using System.Data.OleDb;
using Microsoft.Win32;
using Utils.Misc;
using PhoenixDLL.Class;
using PhoenixDLL.GUI;
using Components.SplashBar;
using PhoenixDLL.GUI.Seekers;

namespace PhoenixAgenda.GUI
{
    /// <summary>
    /// Fentre principale
    /// </summary>
    public partial class fr_Main : Form
    {
        #region Variables
        private const string vApplicName = "Phoenix - Cala";
        /// <summary>
        /// fichier de log
        /// </summary>
        protected Log log = Log.GetInstance();

        /// <summary>
        /// Options de la fentre
        /// </summary>
        protected Options options = Options.GetInstance();

        /// <summary>
        /// MeetingSet contenant toutes les information sur les rendez-vous
        /// </summary>
        protected MeetingSet vMeetingSet = new MeetingSet();
        #endregion

        #region Constructeurs
        /// <summary>
        /// Constructeur
        /// </summary>
        public fr_Main()
        {
            InitializeComponent();
            ma_Month.DateToDisplay = DateTime.Today;
            DrawComponents();
            ShowMonth();
            this.Text = vApplicName;
        }
        #endregion

        #region Mthodes
        /// <summary>
        /// Montre les mois
        /// </summary>
        protected void ShowMonth()
        {
            tb_Month.Visible = false;
            da_Day.Dock = DockStyle.None;
            da_Day.Location = new Point(15000, 15000);
            ma_Month.Location = new Point(0, 0);
            ma_Month.Dock = DockStyle.Fill;
            ma_Month.Focus();
            this.Text = vApplicName;
        }

        /// <summary>
        /// Montre les jours
        /// </summary>
        protected void ShowDay()
        {
            tb_Month.Visible = true;
            ma_Month.Dock = DockStyle.None;
            ma_Month.Location = new Point(15000, 15000);
            da_Day.Location = new Point(0, 0);
            da_Day.Dock = DockStyle.Fill;
            this.Text += " (" + da_Day.DateToDisplay.ToShortDateString() + ")";
        }

        /// <summary>
        /// Dessine les composant sur base des options
        /// </summary>
        protected void DrawComponents()
        {
            #region MonthAgenda
            ma_Month.DaysBackColor = options.DaysBackColor;
            ma_Month.DaysBorderColor = options.DaysBorderColor;
            ma_Month.DaysTextColor = options.DaysTextColor;
            ma_Month.DaysTextFont = options.DaysTextFont;
            ma_Month.DaysNonInMonthColor = options.DaysNonInMonthColor;

            ma_Month.HeaderTextFont = options.HeaderTextFont;
            ma_Month.HeaderTextColor = options.HeaderTextColor;
            ma_Month.HeaderBackColor = options.HeaderBackColor;

            ma_Month.HeaderDayBackColor = options.HeaderDayBackColor;
            ma_Month.HeaderDayTextFont = options.HeaderDayTextFont;
            ma_Month.HeaderDayTextColor = options.HeaderDayTextColor;

            ma_Month.TodayBackColor = options.TodayBackColor;
            #endregion

            #region DayAgenda
            da_Day.FirstMeetingFadeColor = options.FirstMeetingFadeColor;
            da_Day.SecondMeetingFadeColor = options.SecondMeetingFadeColor;
            da_Day.MeetingTextColor = options.MeetingTextColor;
            da_Day.MeetingTextFont = options.MeetingTextFont;
            da_Day.NonMeetingBackColor = options.NonMeetingBackColor;
            da_Day.RefreshComponent();
            #endregion
        }
        #endregion

        #region Event

        #region Menu
        /// <summary>
        /// Clique sur le bouton de demande d'affichage des mois
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_MonthVisible(object sender, EventArgs e)
        {
            //vMeetingSet.Fill();
            //ma_Month.MeetingList = vMeetingSet.MeetingList;
            ShowMonth();
        }

        /// <summary>
        /// Clique sur le bouton d'options
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Options(object sender, EventArgs e)
        {
            fr_Options fr = new fr_Options();
            DialogResult dr = fr.ShowDialog();

            //Demande de mise--jour des options
            if (dr == DialogResult.OK)
            {
                DrawComponents();
                da_Day.RefreshComponent();

                OnPaint(new PaintEventArgs(da_Day.CreateGraphics(), new Rectangle(da_Day.Location, da_Day.Size)));
            }

        }

        /// <summary>
        /// Clique sur une demande d'affichage de la fentre "A propos..."
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_About(object sender, EventArgs e)
        {
            fr_About fr = new fr_About();
            fr.ShowDialog();
        }

        /// <summary>
        /// Clique sur une demande de slection des rendez-vous d'un patient
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_SelectMeetings(object sender, EventArgs e)
        {
            fr_PatientSeeker fr = new fr_PatientSeeker();
            fr.Text = "Recherche du patient...";
            DialogResult dr = fr.ShowDialog();

            if (dr != DialogResult.OK) return;

            fr_MeetingsViewer fm = new fr_MeetingsViewer();
            fm.PatientManager = fr.SelectedItem;
            fm.ShowDialog();

        }
        #endregion

        #region MonthAgenda
        /// <summary>
        /// Clique sur un jour du MonthAgenda
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MonthAgenda_ClickedOnDay(object sender, DayEventArgs e)
        {
            da_Day.DateToDisplay = e.Date;
            da_Day.MeetingList = ma_Month.MeetingList;
            ShowDay();
        }
        #endregion

        #region DayAgenda
        /// <summary>
        /// Demande de rendez-vous
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_MeetingAsked(object sender, MeetingEventArgs e)
        {
            fr_AddMeeting fr = new fr_AddMeeting();
            fr.MeetingInfo = e.MeetingInfo;            
            fr.MeetingSet.MeetingList = ma_Month.MeetingList;

            DialogResult dr = fr.ShowDialog();

            if (dr == DialogResult.OK)            
                da_Day.MeetingList = ma_Month.MeetingList;            


        }

        /// <summary>
        /// Demande de modification d'un rendez-vous
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_MeetingModificationAsked(object sender, MeetingModificationEventArgs e)
        {
            fr_AddMeeting fr = new fr_AddMeeting();
            fr.IsUpdate = true;
            ResultMeetingRow rmr = vMeetingSet.Seek(e.IDMeeting);
            if (rmr.IsResult)
            {

                fr.IdPatient = rmr.Result.IDPatient;
                fr.Title = rmr.Result.Title;
                fr.Message = rmr.Result.Message;
                fr.MeetingInfo = e.MeetingInfo;
                fr.MeetingSet.MeetingList = ma_Month.MeetingList;
                DialogResult dr =  fr.ShowDialog();

                if (dr == DialogResult.OK)
                    da_Day.MeetingList = ma_Month.MeetingList;   
            }
        }
        #endregion

        #endregion

        #region Accesseurs
        /// <summary>
        /// Retourne ou initialise la liste des rendez-vous
        /// </summary>
        public MeetingSet MeetingSet
        {
            get { return vMeetingSet; }
            set
            {
                vMeetingSet = value;
                ma_Month.MeetingList = vMeetingSet.MeetingList;
            }
        }
        #endregion
    }
}